@@ -15,7 +15,6 @@ from .objects.command.payload import CommandPayload
 from .objects.command.response import CommandResponse
 from .objects.cpu import Cpu
 from .objects.display import DisplayBase
-from .objects.display.put import DisplayPutPayload
 from .objects.events import Event, EventBase
 from .objects.filesystem import Filesystem
 from .objects.graphics import Graphics
@@ -297,7 +296,7 @@ class Bridge(BridgeBase):
                     elif name == "cpu":
                         self._cpu = Cpu(event.data)
                     elif name == "display":
-                        self._display = Display(event.data)
+                        self._display = DisplayBase(event.data)
                     elif name == "filesystem":
                         self._filesystem = Filesystem(event.data)
                     elif name == "graphics":
