@@ -23,9 +23,11 @@ class BridgeClient(BridgeBase):
         """Make a POST request."""
         return await self.request("POST", url, **kwargs)
 
-    async def request(
-        self, method: str in ["GET", "POST"], url: str, **kwargs
-    ) -> ClientResponse:
+    async def put(self, url: str, **kwargs) -> ClientResponse:
+        """Make a PUT request."""
+        return await self.request("PUT", url, **kwargs)
+
+    async def request(self, method: str, url: str, **kwargs) -> ClientResponse:
         """Make a request."""
         async with async_timeout.timeout(20, loop=get_event_loop()):
             response: ClientResponse = await self._session.request(
